#!/bin/bash

# Abort if any command fails...
set -e

function get_aws_backup {
  echo "Getting last backup available..."
  BACKUP_NAME=$(docker run -e AWS_ACCESS_KEY_ID=$AWS_ACCESS_KEY_ID -e AWS_SECRET_ACCESS_KEY=$AWS_SECRET_ACCESS_KEY --rm -v /tmp:/tmp amazon/aws-cli s3 ls $BASE_URL|tail -1|tr -s ' '|cut -d' ' -f4)
  echo "-> Latest backup: $BACKUP_NAME"
  echo "Downloading to /tmp/db.sql.gz..."
  docker run -e AWS_ACCESS_KEY_ID=$AWS_ACCESS_KEY_ID -e AWS_SECRET_ACCESS_KEY=$AWS_SECRET_ACCESS_KEY --rm -v /tmp:/tmp amazon/aws-cli s3 cp $BASE_URL$BACKUP_NAME /tmp/db.sql.gz
  echo "-> Downloaded"
}

function stop_container {
  docker-compose stop
  docker-compose up -d db
  echo "Waiting 30s to ensure db is up and running..."
  sleep 30
}

function restore_db {
  echo "drop database $DB_DEST"|docker-compose exec -u postgres -T db psql -U odoo -d postgres
  echo "create database $DB_DEST"|docker-compose exec -u postgres -T db psql -U odoo -d postgres
  gunzip -c /tmp/db.sql.gz|docker-compose exec -u postgres -T db psql -U odoo -d $DB_DEST
  if ! $SKIP_AUTO_CLEAN; then
    curl https://gitlab.eynes.com.ar/infra/eeutils/raw/master/eeutils/templates/auto_clean.sql | docker-compose exec -u postgres -T db psql -U odoo -d $DB_DEST
  fi
}

VALID_ARGS=$(getopt -o sc --long skip-aws,skip-auto-clean -- "$@")

if [[ $? -ne 0 ]]; then
    exit 1;
fi

SKIP_AUTO_CLEAN=false

eval set -- "$VALID_ARGS"
while [ : ]; do
  case "$1" in
    -c | --skip-auto-clean)
      echo "CAUTION: Autoclean will be skipped"
      SKIP_AUTO_CLEAN=true
      shift
      ;;
    -s | --skip-aws)
        echo "Processing from local file located in /tmp"
	stop_container
	restore_db
        break 
        ;;
    *) shift;
	get_aws_backup
	stop_container
	restore_db
        break 
        ;;
  esac

done
